from environs import Env

# read .env file
env = Env()
env.read_env()

# Format: postgresql+{driver}//{user}:{password}@{host}/{name}
# Note that the driver is set by the application.
with env.prefixed("DATABASE_"):
    DATABASE = {
        "USER": env("USER"),
        "PASSWORD": env("PASSWORD"),
        "HOST": env("HOST"),
        "NAME": env("NAME"),
    }

# The Redis database used for Celery and ephemeral storage.
REDIS_URL = env("REDIS_URL", "redis://localhost")

with env.prefixed("MINIO_"):
    MINIO = {
        "ENDPOINT": env("ENDPOINT"),
        "ACCESS_KEY": env("ACCESS_KEY"),
        "SECRET_KEY": env("SECRET_KEY"),
        "BUCKET": env("BUCKET"),
        "SECURE": env.bool("SECURE", True),
        "REGION": env("REGION", "auto"),
    }

# The base domain the API is served on. This must be set.
BASE_DOMAIN = env("BASE_DOMAIN")
# The base domain for short URLs.
SHORT_DOMAIN = env("SHORT_DOMAIN", "prns.localhost")
# The base URL used for the frontend. This will usually be the same as BASE_DOMAIN prefixed with https://.
FRONTEND_BASE = env("FRONTEND_DOMAIN", f"https://{BASE_DOMAIN}")

# Secret key for signing tokens, generate with (for example) `openssl rand -base64 32`
SECRET_KEY = env("SECRET_KEY")

# Whether to echo SQL statements to the logs.
ECHO_SQL = env.bool("ECHO_SQL", False)
